@@ -1,7 +1,7 @@
 /*
  * ServiceConfigurationPage.cpp - page for configuring service application
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -146,7 +146,7 @@ void ServiceConfigurationPage::updateVncServerPluginConfigurationWidget()
 		}
 	}
 
-	emit widgetsChanged();
+	Q_EMIT widgetsChanged();
 }
 
 
