@@ -1,7 +1,7 @@
 /*
  * ComputerControlInterface.h - interface class for controlling a computer
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -141,7 +141,7 @@ private:
 	QTimer m_userUpdateTimer;
 	QTimer m_activeFeaturesUpdateTimer;
 
-signals:
+Q_SIGNALS:
 	void featureMessageReceived( const FeatureMessage&, ComputerControlInterface::Pointer );
 	void screenUpdated();
 	void userChanged();
