@@ -1,7 +1,7 @@
 /*
  * ConfigurationPage.h - base class for all configuration pages
  *
- * Copyright (c) 2016-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2016-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -39,7 +39,7 @@ public:
 	virtual void connectWidgetsToProperties() = 0;
 	virtual void applyConfiguration() = 0;
 
-signals:
+Q_SIGNALS:
 	void widgetsChanged();
 
 };
