@@ -1,7 +1,7 @@
 /*
  * DesktopAccessDialog.h - declaration of DesktopAccessDialog class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -129,7 +129,7 @@ private:
 
 	QTimer m_abortTimer;
 
-signals:
+Q_SIGNALS:
 	void finished();
 
 };
