@@ -1,7 +1,7 @@
 /*
  * FeatureManager.h - header for the FeatureManager class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -59,7 +59,7 @@ public:
 					  const Feature& feature,
 					  const ComputerControlInterfaceList& computerControlInterfaces );
 
-public slots:
+public Q_SLOTS:
 	bool handleFeatureMessage( VeyonMasterInterface& master, const FeatureMessage& message,
 							   const ComputerControlInterface::Pointer& computerControlInterface );
 	bool handleFeatureMessage( VeyonServerInterface& server,
