@@ -1,7 +1,7 @@
 /*
  * KeyboardShortcutTrapper.h - class for trapping system-wide keyboard shortcuts
  *
- * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -50,7 +50,7 @@ public:
 
 	virtual void setEnabled( bool on ) = 0;
 
-signals:
-	void shortcutTrapped( Shortcut );
+Q_SIGNALS:
+	void shortcutTrapped( KeyboardShortcutTrapper::Shortcut );
 
 } ;
