@@ -1,7 +1,7 @@
 /*
  * PlatformServiceCore.h - declaration of PlatformServiceCore class
  *
- * Copyright (c) 2018-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -33,17 +33,12 @@ class VEYON_CORE_EXPORT PlatformServiceCore
 public:
 	using SessionId = int;
 
-	constexpr static SessionId SessionIdInvalid = -1;
-	constexpr static SessionId SessionIdMax = 99;
+	static constexpr SessionId SessionIdInvalid = -1;
+	static constexpr SessionId SessionIdMax = 99;
+	static constexpr auto MaximumSessionCount = SessionIdMax+1;
 
 	PlatformServiceCore();
 
-	SessionId openSession( const QVariant& sessionData );
-	void closeSession( SessionId sessionId );
-
-	QVariant sessionDataFromId( SessionId sessionId ) const;
-	SessionId sessionIdFromData( const QVariant& data ) const;
-
 	bool multiSession() const
 	{
 		return m_multiSession;
