@@ -1,7 +1,7 @@
 /*
  * ToolButton.h - declaration of class ToolButton
  *
- * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -70,7 +70,7 @@ protected:
 	void paintEvent( QPaintEvent * _pe ) override;
 
 
-signals:
+Q_SIGNALS:
 	void mouseLeftButton();
 
 
