@@ -1,7 +1,7 @@
 /*
  * VeyonConnection.h - declaration of class VeyonConnection
  *
- * Copyright (c) 2008-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2008-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -81,7 +81,7 @@ public:
 	static constexpr auto VeyonConnectionTag = 0xFE14A11;
 
 
-signals:
+Q_SIGNALS:
 	void featureMessageReceived( const FeatureMessage& );
 
 private:
