@@ -1,7 +1,7 @@
 /*
  * VeyonCore.h - declaration of VeyonCore class + basic headers
  *
- * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -40,8 +40,6 @@
 #  define VEYON_CORE_EXPORT Q_DECL_IMPORT
 #endif
 
-#define QSL QStringLiteral
-
 class QCoreApplication;
 class QWidget;
 
@@ -153,7 +151,6 @@ public:
 	static void setupApplicationParameters();
 	bool initAuthentication();
 
-	static bool hasSessionId();
 	static int sessionId();
 
 	static QString applicationName();
@@ -218,7 +215,7 @@ private:
 	QString m_authenticationKeyName;
 	bool m_debugging;
 
-signals:
+Q_SIGNALS:
 	void applicationLoaded();
 
 };
