@@ -1,7 +1,7 @@
 /*
  * VncConnection.h - declaration of VncConnection class
  *
- * Copyright (c) 2008-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2008-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -47,6 +47,18 @@ class VEYON_CORE_EXPORT VncConnection : public QThread
 {
 	Q_OBJECT
 public:
+	// intervals and timeouts
+	static constexpr int DefaultThreadTerminationTimeout = 30000;
+	static constexpr int DefaultConnectTimeout = 10000;
+	static constexpr int DefaultReadTimeout = 30000;
+	static constexpr int DefaultConnectionRetryInterval = 1000;
+	static constexpr int DefaultMessageWaitTimeout = 500;
+	static constexpr int DefaultFastFramebufferUpdateInterval = 100;
+	static constexpr int DefaultFramebufferUpdateWatchdogTimeout = 10000;
+	static constexpr int DefaultSocketKeepaliveIdleTime = 1000;
+	static constexpr int DefaultSocketKeepaliveInterval = 500;
+	static constexpr int DefaultSocketKeepaliveCount = 5;
+
 	enum class Quality
 	{
 		Thumbnail,
@@ -140,7 +152,7 @@ public:
 	void keyEvent( unsigned int key, bool pressed );
 	void clientCut( const QString& text );
 
-signals:
+Q_SIGNALS:
 	void connectionPrepared();
 	void connectionEstablished();
 	void imageUpdated( int x, int y, int w, int h );
@@ -155,16 +167,6 @@ protected:
 	void run() override;
 
 private:
-	// intervals and timeouts
-	static constexpr int ThreadTerminationTimeout = 30000;
-	static constexpr int ConnectionRetryInterval = 1000;
-	static constexpr int MessageWaitTimeout = 500;
-	static constexpr int FastFramebufferUpdateInterval = 100;
-	static constexpr int FramebufferUpdateWatchdogTimeout = 10000;
-	static constexpr int SocketKeepaliveIdleTime = 1000;
-	static constexpr int SocketKeepaliveInterval = 500;
-	static constexpr int SocketKeepaliveCount = 5;
-
 	// RFB parameters
 	using RfbPixel = uint32_t;
 	static constexpr int RfbBitsPerSample = 8;
@@ -203,6 +205,18 @@ private:
 	static void rfbClientLogNone( const char* format, ... );
 	static void framebufferCleanup( void* framebuffer );
 
+	// intervals and timeouts
+	int m_threadTerminationTimeout{DefaultThreadTerminationTimeout};
+	int m_connectTimeout{DefaultConnectTimeout};
+	int m_readTimeout{DefaultReadTimeout};
+	int m_connectionRetryInterval{DefaultConnectionRetryInterval};
+	int m_messageWaitTimeout{DefaultMessageWaitTimeout};
+	int m_fastFramebufferUpdateInterval{DefaultFastFramebufferUpdateInterval};
+	int m_framebufferUpdateWatchdogTimeout{DefaultFramebufferUpdateWatchdogTimeout};
+	int m_socketKeepaliveIdleTime{DefaultSocketKeepaliveIdleTime};
+	int m_socketKeepaliveInterval{DefaultSocketKeepaliveInterval};
+	int m_socketKeepaliveCount{DefaultSocketKeepaliveCount};
+
 	// states and flags
 	std::atomic<State> m_state;
 	std::atomic<FramebufferState> m_framebufferState;
@@ -213,6 +227,7 @@ private:
 	Quality m_quality;
 	QString m_host;
 	int m_port;
+	int m_defaultPort{-1};
 
 	// thread and timing control
 	QMutex m_globalMutex;
