@@ -1,7 +1,7 @@
 /*
  * VncServerClient.h - header file for the VncServerClient class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -149,13 +149,13 @@ public:
 		m_privateKey = privateKey;
 	}
 
-public slots:
+public Q_SLOTS:
 	void finishAccessControl()
 	{
-		emit accessControlFinished( this );
+		Q_EMIT accessControlFinished( this );
 	}
 
-signals:
+Q_SIGNALS:
 	void accessControlFinished( VncServerClient* );
 
 private:
