@@ -1,7 +1,7 @@
 /*
  * AccessControlProvider.cpp - implementation of the AccessControlProvider class
  *
- * Copyright (c) 2016-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2016-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -165,8 +165,18 @@ bool AccessControlProvider::processAuthorizedGroups( const QString& accessingUse
 {
 	vDebug() << "processing for user" << accessingUser;
 
-	return intersects( m_userGroupsBackend->groupsOfUser( accessingUser, m_queryDomainGroups ).toSet(),
-					   VeyonCore::config().authorizedUserGroups().toSet() );
+	const auto groupsOfAccessingUser = m_userGroupsBackend->groupsOfUser( accessingUser, m_queryDomainGroups );
+	const auto authorizedUserGroups = VeyonCore::config().authorizedUserGroups();
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+	const auto groupsOfAccessingUserSet = QSet<QString>{ groupsOfAccessingUser.begin(), groupsOfAccessingUser.end() };
+	const auto authorizedUserGroupSet = QSet<QString>{ authorizedUserGroups.begin(), authorizedUserGroups.end() };
+#else
+	const auto groupsOfAccessingUserSet = groupsOfAccessingUser.toSet();
+	const auto authorizedUserGroupSet = authorizedUserGroups.toSet();
+#endif
+
+	return intersects( groupsOfAccessingUserSet, authorizedUserGroupSet );
 }
 
 
@@ -262,7 +272,15 @@ bool AccessControlProvider::haveGroupsInCommon( const QString &userOne, const QS
 	const auto userOneGroups = m_userGroupsBackend->groupsOfUser( userOne, m_queryDomainGroups );
 	const auto userTwoGroups = m_userGroupsBackend->groupsOfUser( userTwo, m_queryDomainGroups );
 
-	return intersects( userOneGroups.toSet(), userTwoGroups.toSet() );
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+	const auto userOneGroupSet = QSet<QString>{ userOneGroups.begin(), userOneGroups.end() };
+	const auto userTwoGroupSet = QSet<QString>{ userTwoGroups.begin(), userTwoGroups.end() };
+#else
+	const auto userOneGroupSet = userOneGroups.toSet();
+	const auto userTwoGroupSet = userTwoGroups.toSet();
+#endif
+
+	return intersects( userOneGroupSet, userTwoGroupSet );
 }
 
 
