@@ -1,7 +1,7 @@
 /*
  * DesktopAccessDialog.cpp - implementation of DesktopAccessDialog class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -53,20 +53,19 @@ DesktopAccessDialog::DesktopAccessDialog( QObject* parent ) :
 
 bool DesktopAccessDialog::isBusy( FeatureWorkerManager* featureWorkerManager ) const
 {
-	return featureWorkerManager->isWorkerRunning( m_desktopAccessDialogFeature );
+	return featureWorkerManager->isWorkerRunning( m_desktopAccessDialogFeature.uid() );
 }
 
 
 
 void DesktopAccessDialog::exec( FeatureWorkerManager* featureWorkerManager, const QString& user, const QString& host )
 {
-	featureWorkerManager->startWorker( m_desktopAccessDialogFeature, FeatureWorkerManager::ManagedSystemProcess );
-
 	m_choice = ChoiceNone;
 
-	featureWorkerManager->sendMessage( FeatureMessage( m_desktopAccessDialogFeature.uid(), RequestDesktopAccess ).
-									   addArgument( UserArgument, user ).
-									   addArgument( HostArgument, host ) );
+	featureWorkerManager->sendMessageToManagedSystemWorker(
+		FeatureMessage( m_desktopAccessDialogFeature.uid(), RequestDesktopAccess )
+			.addArgument( UserArgument, user )
+			.addArgument( HostArgument, host ) );
 
 	connect( &m_abortTimer, &QTimer::timeout, this, [=]() { abort( featureWorkerManager ); } );
 	m_abortTimer.start( DialogTimeout );
@@ -76,11 +75,11 @@ void DesktopAccessDialog::exec( FeatureWorkerManager* featureWorkerManager, cons
 
 void DesktopAccessDialog::abort( FeatureWorkerManager* featureWorkerManager )
 {
-	featureWorkerManager->stopWorker( m_desktopAccessDialogFeature );
+	featureWorkerManager->stopWorker( m_desktopAccessDialogFeature.uid() );
 
 	m_choice = ChoiceNone;
 
-	emit finished();
+	Q_EMIT finished();
 }
 
 
@@ -96,11 +95,11 @@ bool DesktopAccessDialog::handleFeatureMessage( VeyonServerInterface& server,
 	{
 		m_choice = QVariantHelper<Choice>::value( message.argument( ChoiceArgument ) );
 
-		server.featureWorkerManager().stopWorker( m_desktopAccessDialogFeature );
+		server.featureWorkerManager().stopWorker( m_desktopAccessDialogFeature.uid() );
 
 		m_abortTimer.stop();
 
-		emit finished();
+		Q_EMIT finished();
 
 		return true;
 	}
@@ -150,7 +149,7 @@ DesktopAccessDialog::Choice DesktopAccessDialog::requestDesktopAccess( const QSt
 	m.setEscapeButton( m.button( QMessageBox::No ) );
 	m.setDefaultButton( neverBtn );
 
-	VeyonCore::platform().coreFunctions().raiseWindow( &m );
+	VeyonCore::platform().coreFunctions().raiseWindow( &m, true );
 
 	const auto result = m.exec();
 
