@@ -1,7 +1,7 @@
 /*
  * PluginManager.cpp - implementation of the PluginManager class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -69,7 +69,7 @@ void PluginManager::loadPlugins()
 {
 	loadPlugins( QStringLiteral("*") + VeyonCore::sharedLibrarySuffix() );
 
-	emit pluginsLoaded();
+	Q_EMIT pluginsLoaded();
 }
 
 
