@@ -1,7 +1,7 @@
 /*
  * SystemTrayIcon.cpp - implementation of SystemTrayIcon class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -47,55 +47,39 @@ SystemTrayIcon::SystemTrayIcon( QObject* parent ) :
 
 
 void SystemTrayIcon::setToolTip( const QString& toolTipText,
-								 FeatureWorkerManager& featureWorkerManager )
+								FeatureWorkerManager& featureWorkerManager )
 {
-	if( featureWorkerManager.isWorkerRunning( m_systemTrayIconFeature ) == false )
-	{
-		featureWorkerManager.startWorker( m_systemTrayIconFeature, FeatureWorkerManager::UnmanagedSessionProcess );
-	}
-
 	FeatureMessage featureMessage( m_systemTrayIconFeature.uid(), SetToolTipCommand );
 	featureMessage.addArgument( ToolTipTextArgument, toolTipText );
 
-	featureWorkerManager.sendMessage( featureMessage );
+	featureWorkerManager.sendMessageToUnmanagedSessionWorker( featureMessage );
 }
 
 
 
 void SystemTrayIcon::showMessage( const QString& messageTitle,
-								  const QString& messageText,
-								  FeatureWorkerManager& featureWorkerManager  )
+								 const QString& messageText,
+								 FeatureWorkerManager& featureWorkerManager  )
 {
-	if( featureWorkerManager.isWorkerRunning( m_systemTrayIconFeature ) == false )
-	{
-		featureWorkerManager.startWorker( m_systemTrayIconFeature, FeatureWorkerManager::UnmanagedSessionProcess );
-	}
-
 	FeatureMessage featureMessage( m_systemTrayIconFeature.uid(), ShowMessageCommand );
 	featureMessage.addArgument( MessageTitleArgument, messageTitle );
 	featureMessage.addArgument( MessageTextArgument, messageText );
 
-	featureWorkerManager.sendMessage( featureMessage );
+	featureWorkerManager.sendMessageToUnmanagedSessionWorker( featureMessage );
 }
 
 
 
 bool SystemTrayIcon::handleFeatureMessage( VeyonServerInterface& server,
-										   const MessageContext& messageContext,
-										   const FeatureMessage& message )
+										  const MessageContext& messageContext,
+										  const FeatureMessage& message )
 {
 	Q_UNUSED(messageContext)
 
 	if( m_systemTrayIconFeature.uid() == message.featureUid() )
 	{
 		// forward message to worker
-		if( server.featureWorkerManager().isWorkerRunning( m_systemTrayIconFeature ) == false )
-		{
-			server.featureWorkerManager().startWorker( m_systemTrayIconFeature, FeatureWorkerManager::UnmanagedSessionProcess );
-		}
-
-		server.featureWorkerManager().sendMessage( message );
-
+		server.featureWorkerManager().sendMessageToUnmanagedSessionWorker( message );
 		return true;
 	}
 
