@@ -1,7 +1,7 @@
 /*
  * ToolButton.cpp - implementation of Veyon-tool-button
  *
- * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -149,7 +149,7 @@ void ToolButton::leaveEvent( QEvent* event )
 
 void ToolButton::mousePressEvent( QMouseEvent* event )
 {
-	emit mouseLeftButton();
+	Q_EMIT mouseLeftButton();
 	QToolButton::mousePressEvent( event );
 }
 
@@ -233,7 +233,7 @@ bool ToolButton::checkForLeaveEvent()
 	}
 	else
 	{
-		emit mouseLeftButton();
+		Q_EMIT mouseLeftButton();
 		m_mouseOver = false;
 
 		return true;
@@ -332,14 +332,14 @@ void ToolButtonTip::resizeEvent( QResizeEvent * _re )
 	p.setPen( pen );
 	QLinearGradient grad( 0, 0, 0, height() );
 	const QColor color_top = palette().color( QPalette::Active,
-											  QPalette::Window ).light( 120 );
+											  QPalette::Window ).lighter( 120 );
 	grad.setColorAt( 0, color_top );
 	grad.setColorAt( 1, palette().color( QPalette::Active,
 										 QPalette::Window ).
-					 light( 80 ) );
+					 lighter( 80 ) );
 	p.setBrush( grad );
-	p.drawRoundRect( 0, 0, width() - 1, height() - 1,
-					 ROUNDED / width(), ROUNDED / height() );
+	p.drawRoundedRect( 0, 0, width() - 1, height() - 1, ROUNDED / width(), ROUNDED / height() );
+
 	if( m_toolButton )
 	{
 		QPoint pt = m_toolButton->mapToGlobal( QPoint( 0, 0 ) );
@@ -393,8 +393,7 @@ void ToolButtonTip::updateMask()
 	QPainter p( &b );
 	p.setBrush( Qt::color1 );
 	p.setPen( Qt::color1 );
-	p.drawRoundRect( 0, 0, width() - 1, height() - 1,
-					 ROUNDED / width(), ROUNDED / height() );
+	p.drawRoundedRect( 0, 0, width() - 1, height() - 1, ROUNDED / width(), ROUNDED / height() );
 
 	if( m_toolButton )
 	{
