@@ -1,7 +1,7 @@
 /*
  * VeyonCore.cpp - implementation of Veyon Core
  *
- * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -24,8 +24,6 @@
 
 #include <veyonconfig.h>
 
-#include <QLocale>
-#include <QTranslator>
 #include <QAbstractButton>
 #include <QAction>
 #include <QApplication>
@@ -46,7 +44,9 @@
 #include "PlatformPluginManager.h"
 #include "PlatformCoreFunctions.h"
 #include "PlatformServiceCore.h"
+#include "PlatformSessionFunctions.h"
 #include "PluginManager.h"
+#include "TranslationLoader.h"
 #include "UserGroupsBackendManager.h"
 #include "VeyonConfiguration.h"
 #include "VncConnection.h"
@@ -223,16 +223,20 @@ bool VeyonCore::initAuthentication()
 
 
 
-bool VeyonCore::hasSessionId()
-{
-	return QProcessEnvironment::systemEnvironment().contains( sessionIdEnvironmentVariable() );
-}
-
-
-
 int VeyonCore::sessionId()
 {
-	return QProcessEnvironment::systemEnvironment().value( sessionIdEnvironmentVariable() ).toInt();
+	if( config().multiSessionModeEnabled() )
+	{
+		const auto systemEnv = QProcessEnvironment::systemEnvironment();
+		if( systemEnv.contains( sessionIdEnvironmentVariable() ) )
+		{
+			return systemEnv.value( sessionIdEnvironmentVariable() ).toInt();
+		}
+
+		return platform().sessionFunctions().currentSessionId();
+	}
+
+	return PlatformSessionFunctions::DefaultSession;
 }
 
 
@@ -338,7 +342,7 @@ QByteArray VeyonCore::cleanupFuncinfo( QByteArray info )
 	info.replace("operator ", "operator");
 
 	// remove argument list
-	forever {
+	Q_FOREVER {
 		int parencount = 0;
 		pos = info.lastIndexOf(')');
 		if (pos == -1) {
@@ -495,7 +499,7 @@ bool VeyonCore::isAuthenticationKeyNameValid( const QString& authKeyName )
 
 int VeyonCore::exec()
 {
-	emit applicationLoaded();
+	Q_EMIT applicationLoaded();
 
 	vDebug() << "Running";
 
@@ -541,9 +545,11 @@ void VeyonCore::initConfiguration()
 
 void VeyonCore::initLogging( const QString& appComponentName )
 {
-	if( hasSessionId() )
+	const auto currentSessionId = sessionId();
+
+	if( currentSessionId != PlatformSessionFunctions::DefaultSession )
 	{
-		m_logger = new Logger( QStringLiteral("%1-%2").arg( appComponentName ).arg( sessionId() ) );
+		m_logger = new Logger( QStringLiteral("%1-%2").arg( appComponentName ).arg( currentSessionId ) );
 	}
 	else
 	{
@@ -559,40 +565,9 @@ void VeyonCore::initLogging( const QString& appComponentName )
 
 void VeyonCore::initLocaleAndTranslation()
 {
-	QLocale configuredLocale( QLocale::C );
+	TranslationLoader::load( QStringLiteral("qt") );
 
-	QRegExp localeRegEx( QStringLiteral( "[^(]*\\(([^)]*)\\)") );
-	if( localeRegEx.indexIn( config().uiLanguage() ) == 0 )
-	{
-		configuredLocale = QLocale( localeRegEx.cap( 1 ) );
-	}
-
-	if( configuredLocale.language() != QLocale::English )
-	{
-		auto tr = new QTranslator;
-		if( configuredLocale == QLocale::C ||
-			tr->load( QStringLiteral( "%1.qm" ).arg( configuredLocale.name() ), translationsDirectory() ) == false )
-		{
-			configuredLocale = QLocale::system(); // Flawfinder: ignore
-
-			if( tr->load( QStringLiteral( "%1.qm" ).arg( configuredLocale.name() ), translationsDirectory() ) == false )
-			{
-				tr->load( QStringLiteral( "%1.qm" ).arg( configuredLocale.language() ), translationsDirectory() );
-			}
-		}
-
-		QLocale::setDefault( configuredLocale );
-
-		QCoreApplication::installTranslator( tr );
-
-		auto qtTr = new QTranslator;
-		if( qtTr->load( QStringLiteral( "qt_%1.qm" ).arg( configuredLocale.name() ), qtTranslationsDirectory() ) == false )
-		{
-			qtTr->load( QStringLiteral( "qt_%1.qm" ).arg( configuredLocale.language() ), qtTranslationsDirectory() );
-		}
-
-		QCoreApplication::installTranslator( qtTr );
-	}
+	const auto configuredLocale = TranslationLoader::load( QStringLiteral("veyon") );
 
 	if( configuredLocale.language() == QLocale::Hebrew ||
 		configuredLocale.language() == QLocale::Arabic )
