@@ -1,7 +1,7 @@
 /*
  * VncClientProtocol.cpp - implementation of the VncClientProtocol class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -25,7 +25,7 @@
 extern "C"
 {
 #include "rfb/rfbproto.h"
-#include "common/d3des.h"
+#include "d3des.h"
 }
 
 #include <QBuffer>
