@@ -1,7 +1,7 @@
 /*
  * VncView.cpp - VNC viewer widget
  *
- * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -539,7 +539,7 @@ void VncView::keyEventHandler( QKeyEvent* event )
 
 		// signal key event - used by RemoteControlWidget to close itself
 		// when pressing Esc
-		emit keyEvent( key, pressed );
+		Q_EMIT keyEvent( key, pressed );
 
 		// inform Qt that we handled the key event
 		event->accept();
@@ -737,9 +737,14 @@ void VncView::wheelEventHandler( QWheelEvent* event )
 	{
 		return;
 	}
-
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+	const auto p = mapToFramebuffer( event->position().toPoint() );
+	const uint scrollButtonMask = ( event->angleDelta().y() < 0 ) ? rfbButton5Mask : rfbButton4Mask;
+#else
 	const auto p = mapToFramebuffer( event->pos() );
-	m_vncConn->mouseEvent( p.x(), p.y(), m_buttonMask | ( ( event->delta() < 0 ) ? rfbButton5Mask : rfbButton4Mask ) );
+	const uint scrollButtonMask = ( event->delta() < 0 ) ? rfbButton5Mask : rfbButton4Mask;
+#endif
+	m_vncConn->mouseEvent( p.x(), p.y(), m_buttonMask | scrollButtonMask );
 	m_vncConn->mouseEvent( p.x(), p.y(), m_buttonMask );
 }
 
@@ -818,7 +823,7 @@ void VncView::updateImage( int x, int y, int w, int h )
 
 		resize( sizeHint() );
 
-		emit connectionEstablished();
+		Q_EMIT connectionEstablished();
 		m_initDone = true;
 
 	}
@@ -837,7 +842,7 @@ void VncView::updateFramebufferSize( int w, int h )
 
 	resize( w, h );
 
-	emit sizeHintChanged();
+	Q_EMIT sizeHintChanged();
 }
 
 
