@@ -1,7 +1,7 @@
 /*
  * ComputerControlListModel.h - data model for computer control objects
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -76,7 +76,7 @@ public:
 
 	void reload();
 
-signals:
+Q_SIGNALS:
 	void activeFeaturesChanged( QModelIndex );
 
 private:
