@@ -1,7 +1,7 @@
 /*
  * MainWindow.h - main window of Veyon Master Application
  *
- * Copyright (c) 2004-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2004-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -62,7 +62,7 @@ protected:
 	void keyPressEvent( QKeyEvent *e ) override;
 
 
-private slots:
+private Q_SLOTS:
 	void showAboutDialog();
 
 private:
