@@ -1,7 +1,7 @@
 /*
  * VeyonMaster.h - global instances
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -91,7 +91,7 @@ public:
 
 	ComputerControlInterfaceList filteredComputerControlInterfaces();
 
-public slots:
+public Q_SLOTS:
 	void runFeature( const Feature& feature );
 	void enforceDesignatedMode( const QModelIndex& index );
 	void stopAllModeFeatures( const ComputerControlInterfaceList& computerControlInterfaces );
