@@ -1,7 +1,7 @@
 /*
  * DemoClient.cpp - client widget for demo mode
  *
- * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -34,7 +34,7 @@
 #include "VncView.h"
 
 
-DemoClient::DemoClient( const QString& host, bool fullscreen, QObject* parent ) :
+DemoClient::DemoClient( const QString& host, int port, bool fullscreen, QObject* parent ) :
 	QObject( parent ),
 	m_toplevel( nullptr )
 {
@@ -57,10 +57,10 @@ DemoClient::DemoClient( const QString& host, bool fullscreen, QObject* parent )
 		m_toplevel->resize( QApplication::desktop()->availableGeometry( m_toplevel ).size() - QSize( 10, 30 ) );
 	}
 
-	m_vncView = new VncView( host, VeyonCore::config().demoServerPort(), m_toplevel, VncView::DemoMode );
+	m_vncView = new VncView( host, port, m_toplevel, VncView::DemoMode );
 
 	auto toplevelLayout = new QVBoxLayout;
-	toplevelLayout->setMargin( 0 );
+	toplevelLayout->setContentsMargins( 0, 0, 0, 0 );
 	toplevelLayout->setSpacing( 0 );
 	toplevelLayout->addWidget( m_vncView );
 
@@ -79,7 +79,7 @@ DemoClient::DemoClient( const QString& host, bool fullscreen, QObject* parent )
 		m_toplevel->show();
 	}
 
-	VeyonCore::platform().coreFunctions().raiseWindow( m_toplevel );
+	VeyonCore::platform().coreFunctions().raiseWindow( m_toplevel, fullscreen );
 
 	VeyonCore::platform().coreFunctions().disableScreenSaver();
 }
