@@ -1,7 +1,7 @@
 /*
  * DemoFeaturePlugin.cpp - implementation of DemoFeaturePlugin class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -80,8 +80,12 @@ bool DemoFeaturePlugin::startFeature( VeyonMasterInterface& master, const Featur
 
 	if( feature == m_windowDemoFeature || feature == m_fullscreenDemoFeature )
 	{
+		const auto demoServerPort = VeyonCore::config().demoServerPort() + VeyonCore::sessionId();
+
 		FeatureMessage featureMessage( m_demoServerFeature.uid(), StartDemoServer );
 		featureMessage.addArgument( DemoAccessToken, m_demoAccessToken.toByteArray() );
+		featureMessage.addArgument( VncServerPort, VeyonCore::config().vncServerPort() + VeyonCore::sessionId() );
+		featureMessage.addArgument( DemoServerPort, demoServerPort );
 
 		VeyonCore::localComputerControlInterface().sendFeatureMessage( featureMessage, true );
 
@@ -98,7 +102,9 @@ bool DemoFeaturePlugin::startFeature( VeyonMasterInterface& master, const Featur
 
 		vDebug() << "clients:" << m_demoClientHosts;
 
-		return sendFeatureMessage( FeatureMessage( feature.uid(), StartDemoClient ).addArgument( DemoAccessToken, m_demoAccessToken.toByteArray() ),
+		return sendFeatureMessage( FeatureMessage( feature.uid(), StartDemoClient ).
+								   addArgument( DemoAccessToken, m_demoAccessToken.toByteArray() ).
+								   addArgument( DemoServerPort, demoServerPort ),
 								   computerControlInterfaces );
 	}
 
@@ -163,24 +169,21 @@ bool DemoFeaturePlugin::handleFeatureMessage( VeyonServerInterface& server,
 {
 	if( message.featureUid() == m_demoServerFeature.uid() )
 	{
-		if( server.featureWorkerManager().isWorkerRunning( m_demoServerFeature ) == false )
-		{
-			server.featureWorkerManager().startWorker( m_demoServerFeature, FeatureWorkerManager::ManagedSystemProcess );
-		}
-
 		if( message.command() == StartDemoServer )
 		{
 			// add VNC server password to message
 			server.featureWorkerManager().
-					sendMessage( FeatureMessage( m_demoServerFeature.uid(), StartDemoServer ).
-								 addArgument( VncServerPort, VeyonCore::config().vncServerPort() + VeyonCore::sessionId() ).
-								 addArgument( VncServerPassword, VeyonCore::authenticationCredentials().internalVncServerPassword().toByteArray() ).
-								 addArgument( DemoAccessToken, message.argument( DemoAccessToken ) ) );
+				sendMessageToManagedSystemWorker(
+					FeatureMessage( m_demoServerFeature.uid(), StartDemoServer )
+						.addArgument( DemoServerPort, message.argument( DemoServerPort ) )
+						.addArgument( VncServerPort, message.argument( VncServerPort ) )
+						.addArgument( VncServerPassword, VeyonCore::authenticationCredentials().internalVncServerPassword().toByteArray() )
+						.addArgument( DemoAccessToken, message.argument( DemoAccessToken ) ) );
 		}
 		else
 		{
 			// forward message to worker
-			server.featureWorkerManager().sendMessage( message );
+			server.featureWorkerManager().sendMessageToManagedSystemWorker( message );
 		}
 
 		return true;
@@ -191,16 +194,16 @@ bool DemoFeaturePlugin::handleFeatureMessage( VeyonServerInterface& server,
 		// if a demo server is started, it's likely that the demo accidentally was
 		// started on master computer as well therefore we deny starting a demo on
 		// hosts on which a demo server is running - exception: debug mode
-		if( server.featureWorkerManager().isWorkerRunning( m_demoServerFeature ) &&
-				VeyonCore::config().logLevel() < Logger::LogLevel::Debug )
+		if( server.featureWorkerManager().isWorkerRunning( m_demoServerFeature.uid() ) &&
+			VeyonCore::config().logLevel() < Logger::LogLevel::Debug )
 		{
 			return false;
 		}
 
-		if( server.featureWorkerManager().isWorkerRunning( Feature( message.featureUid() ) ) == false &&
-				message.command() != StopDemoClient )
+		if( server.featureWorkerManager().isWorkerRunning( message.featureUid() ) == false &&
+			message.command() == StopDemoClient )
 		{
-			server.featureWorkerManager().startWorker( Feature( message.featureUid() ), FeatureWorkerManager::ManagedSystemProcess );
+			return true;
 		}
 
 		auto socket = qobject_cast<QTcpSocket *>( messageContext.ioDevice() );
@@ -216,12 +219,13 @@ bool DemoFeaturePlugin::handleFeatureMessage( VeyonServerInterface& server,
 			FeatureMessage startDemoClientMessage( message.featureUid(), message.command() );
 			startDemoClientMessage.addArgument( DemoAccessToken, message.argument( DemoAccessToken ) );
 			startDemoClientMessage.addArgument( DemoServerHost, socket->peerAddress().toString() );
-			server.featureWorkerManager().sendMessage( startDemoClientMessage );
+			startDemoClientMessage.addArgument( DemoServerPort, message.argument( DemoServerPort ) );
+			server.featureWorkerManager().sendMessageToManagedSystemWorker( startDemoClientMessage );
 		}
 		else
 		{
 			// forward message to worker
-			server.featureWorkerManager().sendMessage( message );
+			server.featureWorkerManager().sendMessageToManagedSystemWorker( message );
 		}
 
 		return true;
@@ -247,6 +251,7 @@ bool DemoFeaturePlugin::handleFeatureMessage( VeyonWorkerInterface& worker, cons
 											   message.argument( VncServerPassword ).toByteArray(),
 											   message.argument( DemoAccessToken ).toByteArray(),
 											   m_configuration,
+											   message.argument( DemoServerPort ).toInt(),
 											   this );
 			}
 			return true;
@@ -271,10 +276,11 @@ bool DemoFeaturePlugin::handleFeatureMessage( VeyonWorkerInterface& worker, cons
 			if( m_demoClient == nullptr )
 			{
 				const auto demoServerHost = message.argument( DemoServerHost ).toString();
+				const auto demoServerPort = message.argument( DemoServerPort ).toInt();
 				const auto isFullscreenDemo = message.featureUid() == m_fullscreenDemoFeature.uid();
 
 				vDebug() << "connecting with master" << demoServerHost;
-				m_demoClient = new DemoClient( demoServerHost, isFullscreenDemo );
+				m_demoClient = new DemoClient( demoServerHost, demoServerPort, isFullscreenDemo );
 			}
 			return true;
 
