@@ -2,7 +2,7 @@
  * DemoServer.cpp - multi-threaded slim VNC-server for demo-purposes (optimized
  *                   for lot of clients accessing server in read-only-mode)
  *
- * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -36,7 +36,7 @@
 
 
 DemoServer::DemoServer( int vncServerPort, const Password& vncServerPassword, const Password& demoAccessToken,
-						const DemoConfiguration& configuration, QObject *parent ) :
+						const DemoConfiguration& configuration, int demoServerPort, QObject *parent ) :
 	QObject( parent ),
 	m_configuration( configuration ),
 	m_memoryLimit( m_configuration.memoryLimit() * 1024*1024 ),
@@ -58,7 +58,7 @@ DemoServer::DemoServer( int vncServerPort, const Password& vncServerPassword, co
 
 	connect( &m_framebufferUpdateTimer, &QTimer::timeout, this, &DemoServer::requestFramebufferUpdate );
 
-	if( m_tcpServer->listen( QHostAddress::Any, static_cast<quint16>( VeyonCore::config().demoServerPort() ) ) == false )
+	if( m_tcpServer->listen( QHostAddress::Any, demoServerPort ) == false )
 	{
 		vCritical() << "could not listen to demo server port";
 		return;
