@@ -2,7 +2,7 @@
  * DemoServer.h - multi-threaded slim VNC-server for demo-purposes (optimized
  *                for lot of clients accessing server in read-only-mode)
  *
- * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -44,7 +44,7 @@ public:
 	using MessageList = QVector<QByteArray>;
 
 	DemoServer( int vncServerPort, const Password& vncServerPassword, const Password& demoAccessToken,
-				const DemoConfiguration& configuration, QObject *parent );
+				const DemoConfiguration& configuration, int demoServerPort, QObject *parent );
 	~DemoServer() override;
 
 	const DemoConfiguration& configuration() const
