@@ -1,7 +1,7 @@
 /*
  * DemoServerConnection.h - header file for DemoServerConnection class
  *
- * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -46,7 +46,7 @@ public:
 	DemoServerConnection( const Password& demoAccessToken, QTcpSocket* socket, DemoServer* demoServer );
 	~DemoServerConnection() override;
 
-public slots:
+public Q_SLOTS:
 	void processClient();
 	void sendFramebufferUpdate();
 
