@@ -1,7 +1,7 @@
 /*
  * LdapPlugin.h - declaration of LdapPlugin class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -114,7 +114,7 @@ public:
 	ConfigurationPage* createConfigurationPage() override;
 
 
-public slots:
+public Q_SLOTS:
 	CommandLinePluginInterface::RunResult handle_autoconfigurebasedn( const QStringList& arguments );
 	CommandLinePluginInterface::RunResult handle_query( const QStringList& arguments );
 	CommandLinePluginInterface::RunResult handle_help( const QStringList& arguments );
