@@ -1,7 +1,7 @@
 /*
  * LdapDirectory.cpp - class representing the LDAP directory and providing access to directory entries
  *
- * Copyright (c) 2016-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2016-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -48,6 +48,12 @@ LdapDirectory::LdapDirectory( const LdapConfiguration& configuration, QObject* p
 	m_computerHostNameAsFQDN = m_configuration.computerHostNameAsFQDN();
 	m_computerMacAddressAttribute = m_configuration.computerMacAddressAttribute();
 	m_locationNameAttribute = m_configuration.locationNameAttribute();
+
+	if( m_computerDisplayNameAttribute.isEmpty() )
+	{
+		m_computerDisplayNameAttribute = QStringLiteral("cn");
+	}
+
 	if( m_locationNameAttribute.isEmpty() )
 	{
 		m_locationNameAttribute = QStringLiteral("cn");
@@ -64,7 +70,6 @@ LdapDirectory::LdapDirectory( const LdapConfiguration& configuration, QObject* p
 	m_computerLocationsByContainer = m_configuration.computerLocationsByContainer();
 	m_computerLocationsByAttribute = m_configuration.computerLocationsByAttribute();
 	m_computerLocationAttribute = m_configuration.computerLocationAttribute();
-
 }
 
 
@@ -403,10 +408,23 @@ QStringList LdapDirectory::computerLocationEntries( const QString& locationName
 	// computer filter configured?
 	if( m_computersFilter.isEmpty() == false )
 	{
+		const auto computerHostNames = computersByHostName();
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+		auto memberComputersSet = QSet<QString>( memberComputers.begin(), memberComputers.end() );
+		const auto computerHostNameSet = QSet<QString>( computerHostNames.begin(), computerHostNames.end() );
+#else
 		auto memberComputersSet = memberComputers.toSet();
+		const auto computerHostNameSet = computersByHostName().toSet();
+#endif
 
 		// then return intersection of filtered computer list and group members
-		return memberComputersSet.intersect( computersByHostName().toSet() ).toList();
+		const auto computerIntersection = memberComputersSet.intersect( computerHostNameSet );
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+		return { computerIntersection.begin(), computerIntersection.end() };
+#else
+		return computerIntersection.toList();
+#endif
 	}
 
 	return memberComputers;
