@@ -1,7 +1,7 @@
 /*
  * PowerControlFeaturePlugin.cpp - implementation of PowerControlFeaturePlugin class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -180,14 +180,12 @@ bool PowerControlFeaturePlugin::handleFeatureMessage( VeyonServerInterface& serv
 		}
 		else
 		{
-			featureWorkerManager.startWorker( m_powerDownConfirmedFeature, FeatureWorkerManager::ManagedSystemProcess );
-			featureWorkerManager.sendMessage( message );
+			featureWorkerManager.sendMessageToManagedSystemWorker( message );
 		}
 	}
 	else if( message.featureUid() == m_powerDownDelayedFeature.uid() )
 	{
-		featureWorkerManager.startWorker( m_powerDownDelayedFeature, FeatureWorkerManager::ManagedSystemProcess );
-		featureWorkerManager.sendMessage( message );
+		featureWorkerManager.sendMessageToManagedSystemWorker( message );
 	}
 	else if( message.featureUid() == m_rebootFeature.uid() )
 	{
@@ -284,7 +282,7 @@ bool PowerControlFeaturePlugin::confirmFeatureExecution( const Feature& feature,
 				QMessageBox::Yes;
 	}
 
-	return false;
+	return true;
 }
 
 
@@ -358,7 +356,7 @@ void PowerControlFeaturePlugin::confirmShutdown()
 				   tr( "The computer was remotely requested to power down. Do you want to power down the computer now?" ),
 				   QMessageBox::Yes | QMessageBox::No );
 	m.show();
-	VeyonCore::platform().coreFunctions().raiseWindow( &m );
+	VeyonCore::platform().coreFunctions().raiseWindow( &m, true );
 
 	if( m.exec() == QMessageBox::Yes )
 	{
@@ -405,7 +403,7 @@ void PowerControlFeaturePlugin::displayShutdownTimeout( int shutdownTimeout )
 	updateDialog( &dialog, 0 );
 
 	dialog.show();
-	VeyonCore::platform().coreFunctions().raiseWindow( &dialog );
+	VeyonCore::platform().coreFunctions().raiseWindow( &dialog, true );
 
 	QTimer powerdownTimer;
 	powerdownTimer.start( 1000 );
