@@ -1,7 +1,7 @@
 /*
  * RemoteAccessFeaturePlugin.cpp - implementation of RemoteAccessFeaturePlugin class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -28,6 +28,7 @@
 #include "AuthenticationCredentials.h"
 #include "RemoteAccessFeaturePlugin.h"
 #include "RemoteAccessWidget.h"
+#include "VeyonConfiguration.h"
 #include "VeyonMasterInterface.h"
 
 
@@ -68,6 +69,12 @@ const FeatureList &RemoteAccessFeaturePlugin::featureList() const
 bool RemoteAccessFeaturePlugin::startFeature( VeyonMasterInterface& master, const Feature& feature,
 											  const ComputerControlInterfaceList& computerControlInterfaces )
 {
+	if( feature.uid() != m_remoteViewFeature.uid() &&
+		feature.uid() != m_remoteControlFeature.uid() )
+	{
+		return false;
+	}
+
 	// determine which computer to access and ask if neccessary
 	ComputerControlInterface::Pointer remoteAccessComputer;
 
@@ -98,18 +105,14 @@ bool RemoteAccessFeaturePlugin::startFeature( VeyonMasterInterface& master, cons
 		return false;
 	}
 
-	if( feature.uid() == m_remoteViewFeature.uid() )
+	auto viewOnly = feature.uid() == m_remoteViewFeature.uid();
+	if( remoteControlEnabled() == false )
 	{
-		new RemoteAccessWidget( remoteAccessComputer, true );
-
-		return true;
+		viewOnly = true;
 	}
-	else if( feature.uid() == m_remoteControlFeature.uid() )
-	{
-		new RemoteAccessWidget( remoteAccessComputer, false );
 
-		return true;
-	}
+	new RemoteAccessWidget( remoteAccessComputer, viewOnly,
+							remoteViewEnabled() && remoteControlEnabled() );
 
 	return false;
 }
@@ -137,6 +140,11 @@ CommandLinePluginInterface::RunResult RemoteAccessFeaturePlugin::handle_view( co
 		return NotEnoughArguments;
 	}
 
+	if( remoteViewEnabled() == false )
+	{
+		return InvalidCommand;
+	}
+
 	return remoteAccess( arguments.first(), true ) ? Successful : Failed;
 }
 
@@ -149,6 +157,11 @@ CommandLinePluginInterface::RunResult RemoteAccessFeaturePlugin::handle_control(
 		return NotEnoughArguments;
 	}
 
+	if( remoteControlEnabled() == false )
+	{
+		return InvalidCommand;
+	}
+
 	return remoteAccess( arguments.first(), false ) ? Successful : Failed;
 }
 
@@ -172,6 +185,21 @@ CommandLinePluginInterface::RunResult RemoteAccessFeaturePlugin::handle_help( co
 
 
 
+bool RemoteAccessFeaturePlugin::remoteViewEnabled() const
+{
+	return VeyonCore::config().disabledFeatures().contains( m_remoteViewFeature.uid().toString() ) == false;
+
+}
+
+
+
+bool RemoteAccessFeaturePlugin::remoteControlEnabled() const
+{
+	return VeyonCore::config().disabledFeatures().contains( m_remoteControlFeature.uid().toString() ) == false;
+}
+
+
+
 bool RemoteAccessFeaturePlugin::initAuthentication()
 {
 	if( VeyonCore::instance()->initAuthentication() == false )
@@ -196,7 +224,13 @@ bool RemoteAccessFeaturePlugin::remoteAccess( const QString& hostAddress, bool v
 	remoteComputer.setName( hostAddress );
 	remoteComputer.setHostAddress( hostAddress );
 
-	new RemoteAccessWidget( ComputerControlInterface::Pointer::create( remoteComputer ), viewOnly );
+	if( remoteControlEnabled() == false )
+	{
+		viewOnly = true;
+	}
+
+	new RemoteAccessWidget( ComputerControlInterface::Pointer::create( remoteComputer ), viewOnly,
+							remoteViewEnabled() && remoteControlEnabled() );
 
 	qApp->exec();
 
