@@ -1,7 +1,7 @@
 /*
  * RemoteAccessFeaturePlugin.h - declaration of RemoteAccessFeaturePlugin class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -87,12 +87,14 @@ public:
 
 	QString commandHelp( const QString& command ) const override;
 
-private slots:
+private Q_SLOTS:
 	CommandLinePluginInterface::RunResult handle_view( const QStringList& arguments );
 	CommandLinePluginInterface::RunResult handle_control( const QStringList& arguments );
 	CommandLinePluginInterface::RunResult handle_help( const QStringList& arguments );
 
 private:
+	bool remoteViewEnabled() const;
+	bool remoteControlEnabled() const;
 	bool initAuthentication();
 	bool remoteAccess( const QString& hostAddress, bool viewOnly );
 
