@@ -1,7 +1,7 @@
 /*
  *  RemoteAccessWidget.h - widget containing a VNC view and controls for it
  *
- *  Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
+ *  Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
  *
  *  This file is part of Veyon - https://veyon.io
  *
@@ -39,7 +39,8 @@ class RemoteAccessWidgetToolBar : public QWidget
 {
 	Q_OBJECT
 public:
-	RemoteAccessWidgetToolBar( RemoteAccessWidget* parent, bool viewOnly );
+	RemoteAccessWidgetToolBar( RemoteAccessWidget* parent,
+							   bool startViewOnly, bool showViewOnlyToggleButton );
 	~RemoteAccessWidgetToolBar() override = default;
 
 	void appear();
@@ -83,7 +84,8 @@ class RemoteAccessWidget : public QWidget
 {
 	Q_OBJECT
 public:
-	explicit RemoteAccessWidget( const ComputerControlInterface::Pointer& computerControlInterface, bool viewOnly = false );
+	explicit RemoteAccessWidget( const ComputerControlInterface::Pointer& computerControlInterface,
+								 bool startViewOnly, bool showViewOnlyToggleButton );
 	~RemoteAccessWidget() override;
 
 	VncView* vncView() const
