@@ -1,7 +1,7 @@
 /*
  * TextMessageDialog.h - declaration of text message dialog class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -38,7 +38,7 @@ public:
 	TextMessageDialog( QString &msgStr, QWidget *parent );
 	~TextMessageDialog() override;
 
-private slots:
+private Q_SLOTS:
 	void accept() override;
 
 
