@@ -1,7 +1,7 @@
 /*
  * TextMessageFeaturePlugin.cpp - implementation of TextMessageFeaturePlugin class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -114,11 +114,7 @@ bool TextMessageFeaturePlugin::handleFeatureMessage( VeyonServerInterface& serve
 	if( m_textMessageFeature.uid() == message.featureUid() )
 	{
 		// forward message to worker
-		if( server.featureWorkerManager().isWorkerRunning( m_textMessageFeature ) == false )
-		{
-			server.featureWorkerManager().startWorker( m_textMessageFeature, FeatureWorkerManager::UnmanagedSessionProcess );
-		}
-		server.featureWorkerManager().sendMessage( message );
+		server.featureWorkerManager().sendMessageToUnmanagedSessionWorker( message );
 
 		return true;
 	}
