@@ -1,7 +1,7 @@
 /*
  * BuiltinUltraVncServer.cpp - implementation of BuiltinUltraVncServer class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -34,7 +34,6 @@ extern int WinVNCAppMain();
 
 static BuiltinUltraVncServer* vncServerInstance = nullptr;
 
-extern BOOL multi;
 extern HINSTANCE hAppInstance;
 extern DWORD mainthreadId;
 extern HINSTANCE hInstResDLL;
@@ -176,14 +175,14 @@ BuiltinUltraVncServer::~BuiltinUltraVncServer()
 
 
 QWidget* BuiltinUltraVncServer::configurationWidget()
-{
+ {
 	return new UltraVncConfigurationWidget( m_configuration );
-}
+ }
 
 
 
 void BuiltinUltraVncServer::prepareServer()
-{
+ {
 	// initialize global instance handler and main thread ID
 	hAppInstance = GetModuleHandle( nullptr );
 	mainthreadId = GetCurrentThreadId();
@@ -191,36 +190,48 @@ void BuiltinUltraVncServer::prepareServer()
 	hInstResDLL = hAppInstance;
 
 	m_logoffEventFilter = new LogoffEventFilter;
-}
+ }
 
 
 
 void BuiltinUltraVncServer::runServer( int serverPort, const Password& password )
-{
+ {
 	m_serverPort = serverPort;
 	m_password = password;
 
-	// only allow multiple instances when explicitely working with multiple
-	// service instances
-	if( VeyonCore::hasSessionId() )
-	{
-		multi = true;
-	}
+	// run UltraVNC server
+	auto hUser32 = LoadLibrary( "user32.dll" );
+	auto hSHCore = LoadLibrary( "SHCore.dll" );
 
-	// run winvnc-server
-	HMODULE hUser32 = LoadLibrary( "user32.dll" );
-	using SetProcessDPIAwareFunc = BOOL (*)();
-	SetProcessDPIAwareFunc setDPIAware = nullptr;
-	if( hUser32 )
+	using SetProcessDpiAwarenessFunc = HRESULT (WINAPI *)( DWORD );
+	const auto setProcessDpiAwareness =
+		hSHCore ? SetProcessDpiAwarenessFunc( GetProcAddress( hSHCore, "SetProcessDpiAwareness" ) ) : nullptr;
+
+	if( setProcessDpiAwareness )
 	{
-		setDPIAware = reinterpret_cast<SetProcessDPIAwareFunc>( GetProcAddress( hUser32, "SetProcessDPIAware" ) );
+		static constexpr DWORD PROCESS_PER_MONITOR_DPI_AWARE = 2;
+		setProcessDpiAwareness( PROCESS_PER_MONITOR_DPI_AWARE );
+	}
+	else if( hUser32 )
+	{
+		using SetProcessDPIAwareFunc = BOOL (*)();
+		const auto setDPIAware = SetProcessDPIAwareFunc( GetProcAddress( hUser32, "SetProcessDPIAware" ) );
 		if( setDPIAware )
 		{
 			setDPIAware();
 		}
+	}
+
+	if( hUser32 )
+	{
 		FreeLibrary( hUser32 );
 	}
 
+	if( hSHCore )
+	{
+		FreeLibrary( hSHCore );
+	}
+
 	WinVNCAppMain();
 }
 
