@@ -1,7 +1,7 @@
 /*
  * BuiltinX11VncServer.h - declaration of BuiltinX11VncServer class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -75,14 +75,14 @@ public:
 
 	void prepareServer() override;
 
-	void runServer( int serverPort, const QString& password ) override;
+	void runServer( int serverPort, const Password& password ) override;
 
 	int configuredServerPort() override
 	{
 		return -1;
 	}
 
-	QString configuredPassword() override
+	Password configuredPassword() override
 	{
 		return {};
 	}
