@@ -1,7 +1,7 @@
 /*
  * ServerAccessControlManager.cpp - implementation of ServerAccessControlManager
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -139,7 +139,7 @@ void ServerAccessControlManager::performAccessControl( VncServerClient* client )
 		break;
 	}
 
-	emit finished( client );
+	Q_EMIT finished( client );
 }
 
 
