@@ -1,7 +1,7 @@
 /*
  * ServerAuthenticationManager.cpp - implementation of ServerAuthenticationManager
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -100,7 +100,8 @@ void ServerAuthenticationManager::processAuthenticationMessage( VncServerClient*
 	{
 	case VncServerClient::AuthState::Failed:
 	case VncServerClient::AuthState::Successful:
-		emit finished( client );
+		Q_EMIT finished( client );
+		break;
 	default:
 		break;
 	}
