@@ -1,7 +1,7 @@
 /*
  * ServerAuthenticationManager.h - header file for ServerAuthenticationManager
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -50,7 +50,7 @@ public:
 									   VariantArrayMessage& message );
 
 
-signals:
+Q_SIGNALS:
 	void finished( VncServerClient* client );
 
 private:
